package Task::HTML5;
use 5.010;
our $VERSION = '0.103';
1;

__END__

=head1 NAME

Task::HTML5 - install modules for handling HTML5

=head1 DESCRIPTION

This Task installs the following:

=over 4

=item * L<HTML::HTML5::Builder>

=item * L<HTML::HTML5::Entities>

=item * L<HTML::HTML5::Outline>

=item * L<HTML::HTML5::Parser>

=item * L<HTML::HTML5::Sanity>

=item * L<HTML::HTML5::Writer>

=item * L<XML::LibXML>

=item * L<XML::LibXML::PrettyPrint>

=back

=head1 SEE ALSO

L<Task::HTML5::Examples::htmltidy>.

L<Task>.

=head1 AUTHOR

Toby Inkster E<lt>tobyink@cpan.orgE<gt>.

=head1 COPYRIGHT

Copyright 2010-2011 Toby Inkster

This library is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.

=cut
